@@ -521,7 +521,10 @@ class Server(object):
             s.connected = True
             headers = None
             if self.cookie:
-                headers = [('Set-Cookie', self.cookie + '=' + sid)]
+                headers = [(
+                    'Set-Cookie',
+                    self.cookie + '=' + sid + '; path=/; SameSite=Lax'
+                )]
             try:
                 return self._ok(s.poll(), headers=headers, b64=b64,
                                 jsonp_index=jsonp_index)
